@@ -1,2 +1,2 @@
 from beastiary.db.base_class import Base  # noqa
-from beastiary.models.run import Run  # noqa
+from beastiary.models.trace import Trace  # noqa
